###############################
PassportElementErrorReverseSide
###############################


.. automodule:: litegram.types.passport_element_error_reverse_side
    :members:
    :member-order: bysource
    :undoc-members: True
    :exclude-members: model_config,model_fields
